BlocErrorHandler class

Constructors

BlocErrorHandler({void onError(String message, {Object? error, StackTrace? stackTrace})?, void logger(String message)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → void Function(String message)?
final
onError → void Function(String message, {Object? error, StackTrace? stackTrace})?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleError(String message, {Object? error, StackTrace? stackTrace}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited