Emitter<State> class abstract

Interface for emitting states in response to events.

The Emitter provides methods for handling state emissions and working with streams in event handlers. It ensures proper cleanup and cancellation of ongoing operations.

Constructors

Emitter()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDone bool
Whether the associated event handler has completed or been cancelled.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(State state) → void
Emits a new state.
forEach<T>(Stream<T> stream, {required State onData(T data), State onError(Object error, StackTrace stackTrace)?}) Future<void>
Processes elements from a stream and transforms them into new states.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEach<T>(Stream<T> stream, {required void onData(T data), void onError(Object error, StackTrace stackTrace)?}) Future<void>
Processes elements from a stream without transforming the bloc state.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited