buildWhen property
Optional condition to determine if the widget should rebuild. Return false to skip rebuilding for a state change.
Implementation
final bool Function(StreamStatus status)? buildWhen;
Optional condition to determine if the widget should rebuild. Return false to skip rebuilding for a state change.
final bool Function(StreamStatus status)? buildWhen;