ScopeInfo class

Information about a tracked scope.

Annotations

Constructors

ScopeInfo({required String id, required String name, required ScopePhase phase, required DateTime startedAt, required FeatureScope scope})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier - primary key. Generated via monotonic counter on ScopeBloc (deterministic, collision-free).
final
name String
Human-readable name (can collide across instances).
final
phase ScopePhase
Current phase of the scope.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope FeatureScope
Reference to the FeatureScope for disposal.
final
startedAt DateTime
When the scope started.
final

Methods

copyWith({ScopePhase? phase}) ScopeInfo
Create a copy with updated phase.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override