ScopeLifecycleConfig class

Configuration for ScopeLifecycleBloc behavior.

Annotations

Constructors

ScopeLifecycleConfig({Duration cleanupTimeout = const Duration(seconds: 2), void onCleanupTimeout(String scopeId, String scopeName)?})
const

Properties

cleanupTimeout Duration
Default timeout for cleanup operations. Individual EndScopeEvent can override this.
final
hashCode int
The hash code for this object.
no setterinherited
onCleanupTimeout → void Function(String scopeId, String scopeName)?
Called when cleanup times out (for logging/metrics).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited