BlocEntry<T extends JuiceBloc<BlocState> > class
Internal entry tracking a registered bloc's state.
This is an internal implementation detail of BlocScope.
Constructors
- BlocEntry({required T factory(), required BlocLifecycle lifecycle})
Properties
- canCreate → bool
-
Whether a new instance can be created.
no setter
-
closingFuture
↔ Future<
void> ? -
Future tracking an in-progress close operation.
getter/setter pair
- createdAt ↔ DateTime?
-
When the current instance was created.
getter/setter pair
- factory → T Function()
-
Factory function to create bloc instances.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance ↔ T?
-
The current bloc instance, if created.
getter/setter pair
- isActive → bool
-
Whether the bloc is active (created and not closing).
no setter
- isClosing → bool
-
Whether the bloc is currently being closed.
no setter
- leaseCount ↔ int
-
Number of active leases on this bloc.
getter/setter pair
- lifecycle → BlocLifecycle
-
The lifecycle behavior for this bloc.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited