BlocEventSink<Event extends Object?> class
abstract
- Implemented types
-
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isClosed
→ bool
-
Whether the object is closed.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addError(Object error, [StackTrace? stackTrace])
→ void
-
Adds an
error to the sink with an optional stackTrace.
inherited
-
close()
→ FutureOr<void>
-
Closes the current instance.
The returned future completes when the instance has been closed.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
send(Event event)
→ void
-
Adds an
event to the sink.
-
toString()
→ String
-
A string representation of this object.
inherited